#include "inkey.ch"

static aClrTable := {"N","B","G","BG","R","RB","GR","W","N","B","G","GR","BG","R","GR","W"}

* ........................................................................
*
* ..... Module: 		DispColors()
*
* ..... Description:	Internal function of ClrMenu. Displays all possible
*							color combinations.
*
* ..... Parameters:	nX	=	<N> Top Row.
*							nY	= 	<N> Left Column.
*
* ..... Returns:		NIL
*
* ........................................................................
STATIC FUNCTION DispColors( nX, nY )

	local nF, nB
	local cDivide, cSuffix

	for nB = 1 to 16

		cSuffix := if( nB > 8, "*", "" )

		for nF = 1 to 16

			cDivide := if( nF > 8, "+/", "/" )

 			setcolor( aClrTable[nF] + cDivide + aClrTable[nB] + cSuffix )
			@ nX, nY say chr(249)

			nY++

		next

		nX++
		nY -= 16

	next

RETURN NIL

* ........................................................................
*
* ..... Module:		ColorMnu() 
*
* ..... Description:	Displays an inkey menu of all possible color
*							combinations.
*
* ..... Parameters:	nRow		= 	<N> Top Row.
*							nCol		= 	<N> Left Column.
*							[cChar]	= 	<C> Optional character for position
*										  	indicator.
*
* ..... Returns: <C> Selected Color	String <Foreground>/<BackGround>
*
* ........................................................................
FUNCTION ColorMnu( nRow, nCol, cChar )

	* ..... Declare variables
	local nOldCurs := setcursor(0) // Save Cursor and set to OFF.
	local nOldColr := setcolor()	 // Save Calling functions Color setting.

	local nMaxCol := nCol + 15		 // Define Maximum Column Choices.
	local nMaxRow := nRow + 15		 // Define Maximum Row Choices.

	local nX := nRow					 // Preserve Passed row for refernce.
	local nY := nCol					 // Preserve Passed Column.

	local nKey, nFore, nBack
	local cDivide, cSuffix

	* ..... Check for character passed to use as position indicator.
	cChar := if( cChar == NIL, chr(251), cChar )

	* ..... Display all possible color combinations.
	DispColors( nRow, nCol )

	nKey := 0
  	while nKey # K_ENTER

		* ..... Calculate Background from relative row position.
		nBack := ( nX - nRow ) + 1
		nFore := ( nY - nCol ) + 1

		* ..... Calculate color intensity.
		cDivide := if( nFore > 8, "+/", "/" )
		cSuffix := if( nBack > 8, "*", "" )

		* ..... Show selected color.
		setcolor( aClrTable[nFore] + cDivide + aClrTable[nBack] + cSuffix )
		@ nX, nY say chr(251)

		* ..... Wait for KeyPress.
		nKey := inkey(0)

		* ..... Reset Old Character.
		@ nX, nY say chr(249)


		if nKey == K_RIGHT
			nX := iif( nY >= nMaxCol, iif( nX < nMaxRow, nX+1, nRow ), nX )
			nY := iif( nY >= nMaxCol, nCol, nY+1 )

		elseif nKey == K_LEFT
			nX := iif( nY <= nCol, iif( nX > nRow, nX-1, nMaxRow ), nX )
			nY := iif( nY <= nCol, nMaxCol, nY-1 )

		elseif nKey == K_DOWN
			nY := iif( nX >= nMaxRow, iif( nY < nMaxCol, nY+1, nCol ), nY )
			nX := iif( nX >= nMaxRow, nRow, nX+1 )

		elseif nKey == K_UP
			nY := iif( nX <= nRow, iif( nY > nCol, nY-1, nMaxCol ), nY )
			nX := iif( nX <= nRow, nMaxRow, nX-1 )

		elseif nKey == K_PGUP
			nX := nRow

		elseif nKey == K_PGDN
			nX := nMaxRow

		elseif nKey == K_HOME
			nX	:= nRow
			nY := nCol

		elseif nKey == K_END
			nX := nMaxRow
			nY := nMaxCol

		endif

	enddo

	* ..... Restore calling functions environment.
	setcursor( nOldCurs )
	setcolor ( nOldColr )

RETURN aClrTable[ nFore ] + cDivide + aClrTable[ nBack ] + cSuffix
